StateLockManager class final

Constructors

StateLockManager({required String lockFilePath, Duration staleLockTtl = const Duration(minutes: 5), Duration acquireTimeout = const Duration(seconds: 10), Duration pollInterval = const Duration(milliseconds: 50)})

Properties

acquireTimeout Duration
final
hashCode int
The hash code for this object.
no setterinherited
lockFilePath String
final
pollInterval Duration
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
staleLockTtl Duration
final

Methods

acquire({Duration? timeout}) Future<LockAcquisition>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release(LockAcquisition acquisition) Future<void>
toString() String
A string representation of this object.
inherited
withLock<T>(Future<T> action()) Future<T>

Operators

operator ==(Object other) bool
The equality operator.
inherited