LockAcquisition class final
- Annotations
-
- @immutable
Constructors
Properties
- acquiredAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lockFilePath → String
-
final
-
previousOwner
→ Map<
String, Object?> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- staleLockRecovered → bool
-
final
- token → String
-
final
- waitMs → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited