PersistedState class final
Constructors
-
PersistedState({int schemaVersion = 1, String? activeSessionId, Map<
String, SessionState> sessions = const <String, SessionState>{}, String? stickyEndpoint, String? lastMode}) -
const
-
PersistedState.fromJson(Map<
String, Object?> json) -
factory
Properties
- activeSession → SessionState?
-
no setter
- activeSessionId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastMode → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemaVersion → int
-
final
-
sessions
→ Map<
String, SessionState> -
final
- stickyEndpoint → String?
-
final
Methods
-
copyWith(
{int? schemaVersion, String? activeSessionId, bool clearActiveSessionId = false, Map< String, SessionState> ? sessions, String? stickyEndpoint, bool clearStickyEndpoint = false, String? lastMode, bool clearLastMode = false}) → PersistedState -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited