StateStore class final
Constructors
- StateStore({required String path, StateLockManager? lockManager})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- lockManager → StateLockManager
-
final
- path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
) → Future< PersistedState> -
readUnlocked(
) → Future< PersistedState> -
toString(
) → String -
A string representation of this object.
inherited
-
withStateLock<
T> (Future< T> action()) → Future<T> -
write(
PersistedState state) → Future< void> -
writeUnlocked(
PersistedState state) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited